@@ -32,7 +32,7 @@ $^W = 1;
 
 BEGIN { $| = 1; print "1..3\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Net::Traceroute;
+use Net::Traceroute6;
 $loaded = 1;
 
 print "ok 1\n";
@@ -41,7 +41,7 @@ print "ok 1\n";
 
 # Test 2: Create an empty object
 
-my $tr = new Net::Traceroute() || do { print "not ok 2\n" ; exit 1};
+my $tr = new Net::Traceroute6() || do { print "not ok 2\n" ; exit 1};
 print "ok 2\n";
 
 # Test 3: traceroute to self.  localhost doesn't work on some OSes.
@@ -83,7 +83,7 @@ sub test_tr {
     my $hostname = shift;
 
     my $self_tr = $tr->new(host => $hostname, timeout=>30,
-#			   debug => 9,
+			   debug => 9,
 			   );
 
     return() if(!$self_tr);
